@@ -1,4 +1,5 @@
 import sys
+import copy
 import logging
 
 from django.conf import settings
@@ -9,8 +10,8 @@ from django.db.models import signals
 from django.db.models.options import Options
 from django.db.models.loading import register_models, get_model
 from django.db.models.base import ModelBase, subclass_exception, get_absolute_url
-from django.db.models.fields.related import OneToOneRel, ManyToOneRel, OneToOneField
-from django.utils.functional import curry
+from django.db.models.fields.related import OneToOneField
+from django.utils.functional import curry, update_wrapper
 from django.utils.encoding import force_unicode, smart_unicode
 
 from restkit import Resource, RequestFailed
@@ -53,10 +54,14 @@ class ROAModelBase(ModelBase):
 
         new_class.add_to_class('_meta', Options(meta, **kwargs))
         if not abstract:
-            new_class.add_to_class('DoesNotExist',
-                    subclass_exception('DoesNotExist', ObjectDoesNotExist, module))
-            new_class.add_to_class('MultipleObjectsReturned',
-                    subclass_exception('MultipleObjectsReturned', MultipleObjectsReturned, module))
+            new_class.add_to_class('DoesNotExist', subclass_exception('DoesNotExist',
+                    tuple(x.DoesNotExist
+                            for x in parents if hasattr(x, '_meta') and not x._meta.abstract)
+                                    or (ObjectDoesNotExist,), module))
+            new_class.add_to_class('MultipleObjectsReturned', subclass_exception('MultipleObjectsReturned',
+                    tuple(x.MultipleObjectsReturned
+                            for x in parents if hasattr(x, '_meta') and not x._meta.abstract)
+                                    or (MultipleObjectsReturned,), module))
             if base_meta and not base_meta.abstract:
                 # Non-abstract child classes inherit some attributes from their
                 # non-abstract parent (unless an ABC comes before it in the
@@ -77,8 +82,10 @@ class ROAModelBase(ModelBase):
             else:
                 # Proxy classes do inherit parent's default manager, if none is
                 # set explicitly.
-                new_class._default_manager = new_class._default_manager._copy_to_model(new_class)
-                new_class._base_manager = new_class._base_manager._copy_to_model(new_class)
+                new_class._default_manager = \
+                        new_class._default_manager._copy_to_model(new_class)
+                new_class._base_manager = \
+                        new_class._base_manager._copy_to_model(new_class)
 
         # Bail out early if we have already created this class.
         m = get_model(new_class._meta.app_label, name, False)
@@ -101,15 +108,18 @@ class ROAModelBase(ModelBase):
             for parent in [cls for cls in parents if hasattr(cls, '_meta')]:
                 if parent._meta.abstract:
                     if parent._meta.fields:
-                        raise TypeError("Abstract base class containing model fields not permitted for proxy model '%s'." % name)
+                        raise TypeError("Abstract base class containing model "\
+                                        "fields not permitted for proxy model '%s'." % name)
                     else:
                         continue
                 if base is not None:
-                    raise TypeError("Proxy model '%s' has more than one non-abstract model base class." % name)
+                    raise TypeError("Proxy model '%s' has more than one " \
+                                    "non-abstract model base class." % name)
                 else:
                     base = parent
             if base is None:
-                    raise TypeError("Proxy model '%s' has no non-abstract model base class." % name)
+                    raise TypeError("Proxy model '%s' has no non-abstract " \
+                                    "model base class." % name)
             if (new_class._meta.local_fields or
                     new_class._meta.local_many_to_many):
                 raise FieldError("Proxy model '%s' contains model fields."
@@ -205,26 +215,35 @@ class ROAModelBase(ModelBase):
         opts._prepare(cls)
 
         if opts.order_with_respect_to:
-            cls.get_next_in_order = curry(cls._get_next_or_previous_in_order, is_next=True)
-            cls.get_previous_in_order = curry(cls._get_next_or_previous_in_order, is_next=False)
-            setattr(opts.order_with_respect_to.rel.to, 'get_%s_order' % cls.__name__.lower(), curry(method_get_order, cls))
-            setattr(opts.order_with_respect_to.rel.to, 'set_%s_order' % cls.__name__.lower(), curry(method_set_order, cls))
+            cls.get_next_in_order = curry(cls._get_next_or_previous_in_order, 
+                                          is_next=True)
+            cls.get_previous_in_order = curry(cls._get_next_or_previous_in_order, 
+                                              is_next=False)
+            setattr(opts.order_with_respect_to.rel.to, 'get_%s_order' \
+                    % cls.__name__.lower(), curry(method_get_order, cls))
+            setattr(opts.order_with_respect_to.rel.to, 'set_%s_order' \
+                    % cls.__name__.lower(), curry(method_set_order, cls))
 
         # Give the class a docstring -- its definition.
         if cls.__doc__ is None:
-            cls.__doc__ = "%s(%s)" % (cls.__name__, ", ".join([f.attname for f in opts.fields]))
+            cls.__doc__ = "%s(%s)" % (cls.__name__, 
+                                      ", ".join([f.attname for f in opts.fields]))
 
         if hasattr(cls, 'get_absolute_url'):
-            cls.get_absolute_url = curry(get_absolute_url, opts, cls.get_absolute_url)
+            cls.get_absolute_url = update_wrapper(curry(get_absolute_url, opts, cls.get_absolute_url),
+                                                  cls.get_absolute_url)
 
         if hasattr(cls, 'get_resource_url_list'):
-            cls.get_resource_url_list = staticmethod(curry(get_resource_url_list, opts, cls.get_resource_url_list))
+            cls.get_resource_url_list = staticmethod(curry(get_resource_url_list, 
+                                                           opts, cls.get_resource_url_list))
 
         if hasattr(cls, 'get_resource_url_count'):
-            cls.get_resource_url_count = curry(get_resource_url_count, opts, cls.get_resource_url_count)
+            cls.get_resource_url_count = curry(get_resource_url_count, opts, 
+                                               cls.get_resource_url_count)
 
         if hasattr(cls, 'get_resource_url_detail'):
-            cls.get_resource_url_detail = curry(get_resource_url_detail, opts, cls.get_resource_url_detail)
+            cls.get_resource_url_detail = curry(get_resource_url_detail, opts, 
+                                                cls.get_resource_url_detail)
 
         signals.class_prepared.send(sender=cls)
 
@@ -262,7 +281,7 @@ class ROAModel(models.Model):
         else:
             meta = cls._meta
 
-        if origin and not meta.auto_created:
+        if origin and not getattr(meta, "auto_created", False):
             signals.pre_save.send(sender=origin, instance=self, raw=raw)
 
         # If we are in a raw save, save the object exactly as presented.
@@ -280,7 +299,8 @@ class ROAModel(models.Model):
                 # At this point, parent's primary key field may be unknown
                 # (for example, from administration form which doesn't fill
                 # this field). If so, fill it.
-                if field and getattr(self, parent._meta.pk.attname) is None and getattr(self, field.attname) is not None:
+                if field and getattr(self, parent._meta.pk.attname) is None \
+                   and getattr(self, field.attname) is not None:
                     setattr(self, parent._meta.pk.attname, getattr(self, field.attname))
 
                 self.save_base(cls=parent, origin=org)
@@ -296,6 +316,7 @@ class ROAModel(models.Model):
             
             ROA_FORMAT = getattr(settings, "ROA_FORMAT", 'json')
             get_args = {'format': ROA_FORMAT}
+            get_args.update(getattr(settings, "ROA_CUSTOM_ARGS", {}))
             
             serializer = serializers.get_serializer(ROA_FORMAT)
             if hasattr(serializer, 'serialize_object'):
@@ -310,7 +331,7 @@ class ROAModel(models.Model):
                         if field_attr is None:
                             payload[field.attname] = None
                         else:
-                            payload[field.attname] = field_attr.id
+                            payload[field.attname] = field_attr.pk
                                     
                     # Handle all other fields
                     else:
@@ -374,19 +395,22 @@ class ROAModel(models.Model):
     save_base.alters_data = True
 
     def delete(self):
-        assert self._get_pk_val() is not None, "%s object can't be deleted because its %s attribute is set to None." % (self._meta.object_name, self._meta.pk.attname)
+        assert self._get_pk_val() is not None, "%s object can't be deleted " \
+                "because its %s attribute is set to None." \
+                % (self._meta.object_name, self._meta.pk.attname)
                 
         # Deletion in cascade should be done server side.
         resource = Resource(self.get_resource_url_detail())
         
-        logger.debug("""Deleting  : "%s" through %s""" % \
-            (unicode(self).encode(settings.DEFAULT_CHARSET), 
-             resource.uri.encode(settings.DEFAULT_CHARSET)))
-        response = resource.delete()
+        logger.debug(u"""Deleting  : "%s" through %s""" % \
+            (unicode(self), unicode(resource.uri)))
+
+        delete_args = getattr(settings, "ROA_CUSTOM_ARGS", {})
+        response = resource.delete(**delete_args)
 
     delete.alters_data = True
 
-    def _get_unique_checks(self):
+    def _get_unique_checks(self, exclude=None):
         """
         We don't want to check unicity that way for now.
         """
