@@ -64,7 +64,7 @@ class Query(object):
         self.select_related = field_dict
         self.related_select_cols = []
         self.related_select_fields = []
-    
+
     @property
     def parameters(self):
         """
@@ -74,9 +74,17 @@ class Query(object):
         
         # Filtering
         for k, v in self.filters.iteritems():
-            parameters['%s%s' % (ROA_ARGS_NAMES_MAPPING.get('FILTER_', 'filter_'), k)] = v
+            key = '%s%s' % (ROA_ARGS_NAMES_MAPPING.get('FILTER_', 'filter_'), k)
+            if key in ROA_ARGS_NAMES_MAPPING:
+                parameters[ROA_ARGS_NAMES_MAPPING[key]] = v
+            else:
+                parameters[key] = v
         for k, v in self.excludes.iteritems():
-            parameters['%s%s' % (ROA_ARGS_NAMES_MAPPING.get('EXCLUDE_', 'exclude_'), k)] = v
+            key = '%s%s' % (ROA_ARGS_NAMES_MAPPING.get('EXCLUDE_', 'exclude_'), k)
+            if key in ROA_ARGS_NAMES_MAPPING:
+                parameters[ROA_ARGS_NAMES_MAPPING[key]] = v
+            else:
+                parameters[key] = v
         
         # Ordering
         if self.order_by:
@@ -127,6 +135,7 @@ class RemoteQuerySet(query.QuerySet):
         self._result_cache = None
         self._iter = None
         self._sticky_filter = False
+        self._db = False
         
         self.params = {}
     
@@ -167,7 +176,7 @@ class RemoteQuerySet(query.QuerySet):
         except Exception, e:
             raise ROAException(e)
 
-        response = force_unicode(response).encode(settings.DEFAULT_CHARSET)
+        response = force_unicode(response.body).encode(settings.DEFAULT_CHARSET)
         for local_name, remote_name in ROA_MODEL_NAME_MAPPING:
             response = response.replace(remote_name, local_name)
         
@@ -202,11 +211,11 @@ class RemoteQuerySet(query.QuerySet):
         except Exception, e:
             raise ROAException(e)
         
-        return int(response)
+        return int(response.body)
 
-    def _get_from_id(self, id):
+    def _get_from_id_or_pk(self, id=None, pk=None):
         """
-        Returns an object given an id, request directly with the
+        Returns an object given an id or pk, request directly with the
         get_resource_url_detail method without filtering on ids
         (as Django's ORM do).
         """
@@ -216,7 +225,10 @@ class RemoteQuerySet(query.QuerySet):
         # a staticmethod for get_resource_url_detail and avoid to set it
         # for all model without relying on get_resource_url_list
         instance = clone.model()
-        instance.id = id
+        if pk is None:
+            instance.id = id
+        else:
+            instance.pk = pk
         resource = Resource(instance.get_resource_url_detail(), headers=ROA_HEADERS)
         
         try:
@@ -230,7 +242,7 @@ class RemoteQuerySet(query.QuerySet):
         except Exception, e:
             raise ROAException(e)
         
-        response = force_unicode(response).encode(settings.DEFAULT_CHARSET)
+        response = force_unicode(response.body).encode(settings.DEFAULT_CHARSET)
         for local_name, remote_name in ROA_MODEL_NAME_MAPPING:
             response = response.replace(remote_name, local_name)
         
@@ -251,7 +263,9 @@ class RemoteQuerySet(query.QuerySet):
         # special case, get(id=X) directly request the resource URL and do not
         # filter on ids like Django's ORM do.
         if kwargs.keys() == ['id']:
-            return self._get_from_id(kwargs['id'])
+            return self._get_from_id_or_pk(id=kwargs['id'])
+        elif kwargs.keys() == ['pk']: # useful for admin which relies on pks
+            return self._get_from_id_or_pk(pk=kwargs['pk'])
         else:
             return super(RemoteQuerySet, self).get(*args, **kwargs)
 
@@ -393,66 +407,22 @@ class RemoteQuerySet(query.QuerySet):
             return FakeInt(self.count())
         raise ROANotImplementedYetException, 'extra is not yet fully implemented.'
 
-    #################################
-    # METHODS THAT DO M2M RELATIONS #
-    #################################
-
-    def _add_items(self, source_col_name=None, target_col_name=None, 
-                   join_table=None, pk_val=None, instance=None, field=None, 
-                   *objs):
-        """
-        Adds m2m relations between ``instance`` object and ``objs``.
-        """
-        if objs:
-            from django.db.models.base import Model
-            # Check that all the objects are of the right type
-            existing_ids = set(obj.id for obj in field.value_from_object(instance))
-            for obj in objs:
-                if isinstance(obj, self.model):
-                    existing_ids.add(obj._get_pk_val())
-                elif isinstance(obj, Model):
-                    raise TypeError, "'%s' instance expected" % self.model._meta.object_name
-                else:
-                    existing_ids.add(obj)
-            # FIXME: ugly but we set manually updated_ids to the instance
-            # before saving it, get back in save_model to send appropriated
-            # ids to the server
-            setattr(instance, '%s_updated_ids' % field.attname, existing_ids)
-            instance.save()
-
-    def _remove_items(self, source_col_name=None, target_col_name=None, 
-                      join_table=None, pk_val=None, instance=None, field=None, 
-                      *objs):
-        """
-        Removes m2m relations between ``instance`` object and ``objs``.
-        """
-        if objs:
-            from django.db.models.base import Model
-            # Check that all the objects are of the right type
-            existing_ids = set(obj.id for obj in field.value_from_object(instance))
-            for obj in objs:
-                if isinstance(obj, self.model):
-                    existing_ids.remove(obj._get_pk_val())
-                elif isinstance(obj, Model):
-                    raise TypeError, "'%s' instance expected" % self.model._meta.object_name
-                else:
-                    existing_ids.remove(obj)
-            setattr(instance, '%s_updated_ids' % field.attname, existing_ids)
-            instance.save()
-
-    def _clear_items(self, source_col_name=None, join_table=None, pk_val=None, 
-                     instance=None, field=None):
-        """
-        Clears m2m relations related to ``instance`` object.
-        """
-        setattr(instance, '%s_updated_ids' % field.attname, [])
-        instance.save()
-
-
     ###################
     # PRIVATE METHODS #
     ###################
 
+    def _clone(self, klass=None, setup=False, **kwargs):
+        if klass is None:
+            klass = self.__class__
+        query = self.query.clone()
+        if self._sticky_filter:
+            query.filter_is_sticky = True
+        c = klass(model=self.model, query=query)
+        c.__dict__.update(kwargs)
+        if setup and hasattr(c, '_setup_query'):
+            c._setup_query()
+        return c
+
     def _as_url(self):
         """
         Returns the internal query's URL and parameters 
