@@ -56,10 +56,19 @@ class RemotePageWithOverriddenUrls(models.Model):
         return u'%s (%s)' % (self.title, self.id)
 
 
+class RemotePageWithRelationsThrough(models.Model):
+    title = models.CharField(max_length=50)
+    remote_page_with_relations = models.ForeignKey("RemotePageWithRelations", blank=True, null=True)
+    remote_page_with_many_fields = models.ForeignKey("RemotePageWithManyFields", blank=True, null=True)
+
+    def __unicode__(self):
+        return u'%s (%s)' % (self.title, self.id)
+
+
 class RemotePageWithRelations(models.Model):
     title = models.CharField(max_length=50)
     remote_page = models.ForeignKey(RemotePage, blank=True, null=True)
-    remote_page_fields = models.ManyToManyField(RemotePageWithManyFields, blank=True, null=True)
+    remote_page_fields = models.ManyToManyField(RemotePageWithManyFields, through=RemotePageWithRelationsThrough, blank=True, null=True)
 
     def __unicode__(self):
         return u'%s (%s)' % (self.title, self.id)
