@@ -47,11 +47,4 @@ PISTON_DISPLAY_ERRORS = False
 
 ## Logging settings
 import logging
-# create logger
-logger = logging.getLogger("django_roa_server")
-logger.setLevel(logging.DEBUG)
-# create console handler and set level to debug
-ch = logging.StreamHandler()
-ch.setLevel(logging.DEBUG)
-ch.setFormatter(logging.Formatter("%(name)s - %(message)s"))
-logger.addHandler(ch)
+logging.basicConfig(level=logging.DEBUG, format="%(name)s - %(message)s")
